@@ -1,4 +1,13 @@
-class Context:
+class Singleton(type):
+    _instances = {}
+
+    def __call__(cls, *args, **kwargs):
+        if cls not in cls._instances:
+            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+        return cls._instances[cls]
+
+
+class Context(metaclass=Singleton):
     endpoints = {}
     checksums = {}
 
